@@ -104,7 +104,7 @@ const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
 const char *http_fn_aen		= "Accept-Encoding:";
-const char *http_fv_srv		= "nostromo 1.8.2";
+const char *http_fv_srv		= "nostromo 1.8.4";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -407,7 +407,7 @@ main(int argc, char *argv[])
 	SSL_CTX			*ssl_ctx = NULL;
 	FILE			*file;
 
-	i = r = s = rd = sdmax = 0;
+	i = r = s = rd = sdmax = sdnow = 0;
 	sdlis1 = sdlis2 = sdlis3 = sdlis4 = -1;
 
 	/*
@@ -983,12 +983,14 @@ main(int argc, char *argv[])
 		tv.tv_sec = TON;
 		tv.tv_usec = 0;
 		if (select(sdmax + 1, &set_r, &set_w, NULL, &tv) == -1) {
-			if (errno == EINTR)
+			if (errno == EINTR) {
 				usleep(1);
-			else
-				flogd(config.logserver, "[error] select: %s\n",
-				    strerror(errno));
-			continue;
+				continue;
+			}
+			/* EFAULT, EBADF, and EINVAL are not acceptable */
+			flogd(config.logserver, "[fatal] select: %s\n",
+			    strerror(errno));
+			break;
 		}
 
 		/* check all existing connections */
@@ -1316,6 +1318,7 @@ main(int argc, char *argv[])
 				free(c[sdnow].wbuf);
 				close(sdnow);
 				FD_CLR(sdnow, &master_r);
+				FD_CLR(sdnow, &master_w);
 			}
 		}
 	}
